code_builder/builder_utils library

Classes

DependencyList
A utility class that provides methods for sorting dependencies and looking up dependencies based on their type and instance name.

Functions

hasPreResolvedDependencies(Iterable<DependencyConfig> deps) bool
Checks if a given DependencyConfig has any asynchronous dependencies.
lookupDependency(InjectedDependency iDep, List<DependencyConfig> allDeps) DependencyConfig?
Resolves a DartType to an ImportableType, which includes information about the type's name, nullability, and required imports.
lookupDependencyWithNoEnvOrHasAny(InjectedDependency iDep, List<DependencyConfig> allDeps, List<String> envs) DependencyConfig?
Resolves a DartType to an ImportableType, which includes information about the type's name, nullability, and required imports. Optionally takes an ExecutableElement to provide additional context for resolving the function type.
lookupPossibleDeps(InjectedDependency iDep, Iterable<DependencyConfig> allDeps) Set<DependencyConfig>
A resolver that converts DartTypes into ImportableTypes, which include information about the type's name, nullability, and required imports. It also handles function types and parameterized types.
nullableRefer(String symbol, {String? url, bool nullable = false}) → TypeReference
A resolver that converts DartTypes into ImportableTypes, which include information about the type's name, nullability, and required imports. It also handles function types and parameterized types.
sortDependencies(List<DependencyConfig> it) List<DependencyConfig>
A resolver that converts DartTypes into ImportableTypes, which include information about the type's name, nullability, and required imports. It also handles function types and parameterized types.
typeRefer(ImportableType type, [Uri? targetFile, bool withNullabilitySuffix = true]) → Reference
A resolver that converts DartTypes into ImportableTypes, which include information about the type's name, nullability, and required imports. It also handles function types and parameterized types.