allDependencies property
All dependencies across scopes, used for determining module overrides and async dependencies.
Implementation
final DependencyList allDependencies;
All dependencies across scopes, used for determining module overrides and async dependencies.
final DependencyList allDependencies;