allowMultipleRegistrations property

bool allowMultipleRegistrations
final

Allows multiple registrations of the same type within this scope, which can be useful for certain testing scenarios or when using named instances. When true, it enables the enableRegisteringMultipleInstancesOfOneType flag on GetIt.

Implementation

final bool allowMultipleRegistrations;