isMicroPackage property
Indicates whether this initializer is being generated for a micro-package module, which affects the return type and method signature.
Implementation
final bool isMicroPackage;
Indicates whether this initializer is being generated for a micro-package module, which affects the return type and method signature.
final bool isMicroPackage;