usesConstructorCallback property
Indicates whether to wrap instance creation with a constructor callback, allowing for custom logic to be applied to all instances after construction.
Implementation
final bool usesConstructorCallback;
Indicates whether to wrap instance creation with a constructor callback, allowing for custom logic to be applied to all instances after construction.
final bool usesConstructorCallback;