initializerName property
The name of the initializer method to generate for the root scope, which will be called to register dependencies in GetIt.
Implementation
final String initializerName;
The name of the initializer method to generate for the root scope, which will be called to register dependencies in GetIt.
final String initializerName;