microPackagesModulesAfter property
The sets of external modules that should be initialized before and after registering the dependencies in this library,
used for micro-package module chaining. The microPackagesModulesBefore set contains modules that should be initialized
before the dependencies in this library, while the microPackagesModulesAfter set contains modules that should be initialized after. These sets are used to generate the appropriate initialization code in the generated library.
Implementation
final Set<ExternalModuleConfig> microPackagesModulesBefore,
microPackagesModulesAfter;