usesConstructorCallback property
The name of the initializer method to generate for the root scope, which will be called to register dependencies in GetIt.
Implementation
final bool usesConstructorCallback;
The name of the initializer method to generate for the root scope, which will be called to register dependencies in GetIt.
final bool usesConstructorCallback;