asExtension property
bool
get
asExtension
A flag indicating whether to generate extension methods for registration or standalone functions.
Implementation
bool get asExtension;
A flag indicating whether to generate extension methods for registration or standalone functions.
bool get asExtension;