InjectableType class

Represents the different registration types for injectable dependencies.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

factory → const int
Factory registration - creates a new instance each time.
lazySingleton → const int
Lazy singleton registration - creates one instance on first access.
singleton → const int
Singleton registration - creates one instance eagerly.