InjectableConfigGenerator class
Generates the final .config.dart file for lean builder.
- Annotations
-
- @LeanGenerator.new({'.config.dart', '.module.dart'}, key: 'InjectableConfigGenerator', registerTypes: {InjectableInit})
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- throwOnUnresolved → bool
-
Whether to throw an exception if no annotated elements are found.
finalinherited
Methods
-
buildTypeChecker(
Resolver resolver) → TypeChecker -
Creates a TypeChecker for this generator's annotation type.
inherited
-
generate(
LibraryElement library, BuildStep buildStep) → FutureOr< String> -
Generates Dart code for an input Dart library.
inherited
-
generateForAnnotatedElement(
BuildStep buildStep, Element element, ElementAnnotation annotation) → dynamic -
Generates code for a single annotated element.
inherited
-
generateForFunction(
BuildStep buildStep, FunctionElement element, ElementAnnotation anno) → dynamic - Generates code for an annotated function element.
-
getTypeChecker(
BuildStep buildStep) → TypeChecker -
Gets a TypeChecker for this generator's annotation type.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited