LeanTypeResolverImpl class

Inheritance

Constructors

LeanTypeResolverImpl(Resolver _resolver)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveFunctionType(FunctionType function, [ExecutableElement? executableElement]) ImportableType
override
resolveImports(DartType? type) Set<String>
override
resolveType(DartType type) ImportableType
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited