DisposeFunctionConfig class

Configuration for a dispose function on a singleton.

Constructors

DisposeFunctionConfig({bool isInstance = false, required String name, ImportableType? importableType})
Creates a DisposeFunctionConfig with the given parameters.
const
DisposeFunctionConfig.fromJson(Map<String, dynamic> json)
Creates a DisposeFunctionConfig from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
importableType ImportableType?
The importable type for external dispose functions, if applicable.
final
isInstance bool
Whether the dispose function is an instance method.
final
name String
The name of the dispose function.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isInstance, String? name, ImportableType? importableType}) DisposeFunctionConfig
Creates a copy of this DisposeFunctionConfig with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this DisposeFunctionConfig to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override