ExternalModuleConfig class

Configuration for an external package module.

Constructors

ExternalModuleConfig(ImportableType module, [String? scope])
Creates an ExternalModuleConfig with the given parameters.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
module ImportableType
The module type.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String?
The scope for this module, if applicable.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override