InjectedDependency class

Represents a dependency that is injected into a constructor or method.

Constructors

InjectedDependency({required ImportableType type, required String paramName, String? instanceName, bool isFactoryParam = false, bool isPositional = true, bool isRequired = true})
Creates an InjectedDependency with the given parameters.
InjectedDependency.fromJson(Map<String, dynamic> json)
Creates an InjectedDependency from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
instanceName String?
The named instance to resolve, or null for default instance.
getter/setter pair
isFactoryParam bool
Whether this dependency is a factory parameter.
getter/setter pair
isPositional bool
Whether this dependency is passed as a positional parameter.
getter/setter pair
isRequired bool
Whether this dependency is required.
getter/setter pair
paramName String
The parameter name in the constructor or method.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ImportableType
The type of the dependency.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this InjectedDependency to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override