ModuleConfig class

Configuration for a module containing abstract dependency registrations.

Constructors

ModuleConfig({required bool isAbstract, required bool isMethod, required ImportableType type, required String initializerName})
Creates a ModuleConfig with the given parameters.
const
ModuleConfig.fromJson(Map<String, dynamic> json)
Creates a ModuleConfig from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
initializerName String
The name of the initializer method.
final
isAbstract bool
Whether the module is abstract.
final
isMethod bool
Whether the module member is a method rather than a getter.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ImportableType
The type of the module.
final

Methods

copyWith({bool? isAbstract, bool? isModuleMethod, ImportableType? module, String? initializerName}) ModuleConfig
Creates a copy of this ModuleConfig with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this ModuleConfig to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override