ImportableTypeResolverImpl class

Implementation of ImportableTypeResolver using the analyzer package.

Inheritance

Constructors

ImportableTypeResolverImpl(List<LibraryElement> libs)
Creates an ImportableTypeResolverImpl with the given libraries.

Properties

hashCode int
The hash code for this object.
no setterinherited
libs List<LibraryElement>
The library elements to search for element imports.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveFunctionType(FunctionType function, [ExecutableElement? executableElement]) ImportableType
Resolves a function type to an ImportableType.
override
resolveImports(Element? element) Set<String>
Resolves the import paths for the given element.
override
resolveType(DartType type) ImportableType
Resolves a DartType to an ImportableType.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited