code_builder/library_builder
library
Classes
-
InitMethodGenerator
-
Generates the initialization method for a specific scope (or the root scope)
to register all dependencies within that scope into GetIt.
-
LibraryGenerator
-
Generates the library code containing extension methods, accessor methods,
initialization functions, and module implementations for a set of dependencies.
Mixins
-
SharedGeneratorCode
-
A library that generates code for registering dependencies in GetIt based on a list of DependencyConfigs.
It supports generating code for different scopes, handling asynchronous dependencies, and integrating with external modules.