allowMultipleRegistrations property
Allows multiple registrations of the same type within this library, which can be useful for certain testing
scenarios or when using named instances. When true, it enables the enableRegisteringMultipleInstancesOfOneType flag on GetIt.
Implementation
final bool allowMultipleRegistrations;