SharedGeneratorCode mixin
A library that generates code for registering dependencies in GetIt based on a list of DependencyConfigs. It supports generating code for different scopes, handling asynchronous dependencies, and integrating with external modules.
- Mixin applications
Properties
- asExtension → bool
-
A flag indicating whether to generate extension methods for registration or standalone functions.
no setter
- dependencies → DependencyList
-
A list of dependencies to be registered, wrapped in a DependencyList for additional functionality.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetFile → Uri?
-
The target file URI for resolving imports, which can be used to generate relative import paths.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited