InjectableGenerator class
Generates intermediate .injectable.json files containing serialized dependency configurations.
Constructors
- InjectableGenerator(Map options)
-
Creates an InjectableGenerator with the given
options.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
LibraryReader library, BuildStep buildStep) → FutureOr< String?> -
Generates JSON configuration for all injectable classes in
library. -
getResolver(
List< LibraryElement> libs) → ImportableTypeResolver - Returns an ImportableTypeResolverImpl for the given libraries.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited