LeanDependencyResolver class
Lean implementation of dependency resolution for DependencyConfig generation.
Constructors
- LeanDependencyResolver(LeanTypeResolver _typeResolver)
- Default constructor
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
ClassElement element) → DependencyConfig -
Resolves a
ClassElementinto a DependencyConfig. -
resolveModuleMember(
ClassElement moduleClazz, ExecutableElement executableElement) → DependencyConfig - Resolves a module member into a DependencyConfig.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited