resolver_utils library
Functions
-
reportMissingDependencies(
List< DependencyConfig> deps, Iterable<ImportableType> ignoredTypes, Iterable<String> ignoredTypesInPackages, Uri? targetFile, bool throwOnMissingDependencies) → void - Validates that all dependencies in the list of DependencyConfigs are registered and available under the correct environment keys.
-
validateDuplicateDependencies(
List< DependencyConfig> deps) → void - Validates that there are no duplicate dependencies in the list of DependencyConfigs.