DependencyResolver class

Resolves a DependencyConfig from a given ClassElement or a module member ExecutableElement by reading the annotations and parameters of the element.

Constructors

DependencyResolver(ImportableTypeResolver _typeResolver)
Creates a new instance of DependencyResolver with the given ImportableTypeResolver.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(ClassElement element) DependencyConfig
Resolves a DependencyConfig from the given ClassElement by reading its annotations and parameters.
resolveModuleMember(ClassElement moduleClazz, ExecutableElement executableElement) DependencyConfig
Resolves a DependencyConfig from the given module member ExecutableElement by reading its annotations and parameters. The moduleClazz parameter is used to resolve the type of the module that contains the member.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited